summaryrefslogtreecommitdiffstats
path: root/mojo/shell/background/background_shell.h
diff options
context:
space:
mode:
authorben <ben@chromium.org>2016-02-27 00:53:31 -0800
committerCommit bot <commit-bot@chromium.org>2016-02-27 08:54:21 +0000
commitc6eb8ad71579f9945976e5b4b4915f084388e5ae (patch)
treee52c8143199b096bbb8b91f4445e0778702d6371 /mojo/shell/background/background_shell.h
parent2d1f2621d8e6dd10feba6cab380fb46d60cb3098 (diff)
downloadchromium_src-c6eb8ad71579f9945976e5b4b4915f084388e5ae.zip
chromium_src-c6eb8ad71579f9945976e5b4b4915f084388e5ae.tar.gz
chromium_src-c6eb8ad71579f9945976e5b4b4915f084388e5ae.tar.bz2
Change Mojo URLs to structured names.
type:path Remove GURLs from all over the place. This eliminates the need to register Mojo and Exe schemes. BUG= CQ_INCLUDE_TRYBOTS=tryserver.chromium.linux:linux_site_isolation Review URL: https://codereview.chromium.org/1743473002 Cr-Commit-Position: refs/heads/master@{#378130}
Diffstat (limited to 'mojo/shell/background/background_shell.h')
-rw-r--r--mojo/shell/background/background_shell.h8
1 files changed, 3 insertions, 5 deletions
diff --git a/mojo/shell/background/background_shell.h b/mojo/shell/background/background_shell.h
index 6226f89..95248b1 100644
--- a/mojo/shell/background/background_shell.h
+++ b/mojo/shell/background/background_shell.h
@@ -13,8 +13,6 @@
#include "mojo/services/package_manager/package_manager.h"
#include "mojo/shell/public/interfaces/shell_client.mojom.h"
-class GURL;
-
namespace package_manager {
class ApplicationCatalogStore;
}
@@ -45,9 +43,9 @@ class BackgroundShell {
// switches applied to any processes spawned by this call.
void Init(scoped_ptr<InitParams> init_params);
- // Obtains an InterfaceRequest for the specified url.
- InterfaceRequest<mojom::ShellClient> CreateShellClientRequest(
- const GURL& url);
+ // Obtains an InterfaceRequest for the specified name.
+ mojom::ShellClientRequest CreateShellClientRequest(
+ const std::string& name);
private:
class MojoThread;